@@ -4,7 +4,7 @@
 //! ```toml
 //! # Cargo.toml
 //! [dependencies]
-//! totp_rfc6238 = { version = "0.4.0", features = [ "oathuri" ]}
+//! totp_rfc6238 = { version = "0.4.1", features = [ "oathuri" ]}
 //! ```
 //!
 //! The functions and methods in this module will automatically try to
@@ -245,7 +245,7 @@ impl TotpUri {
         let parameters = parsed.query_pairs();
         let mut map_parameters = HashMap::new();
         for (k, v) in parameters {
-            map_parameters.insert(k, v);
+            map_parameters.insert(k.to_ascii_lowercase(), v);
         }
 
         let parameter_secret = match map_parameters.get("secret") {
@@ -326,7 +326,7 @@ impl TotpUri {
         uri.zeroize();
         Ok(output)
     }
-    /// Write the infomations and configurations to the TOTOP URIs.
+    /// Write the infomations and configurations to the TOTP URIs.
     ///
     /// # Example
     /// ```
